==> aika-debugger-2.0.2.ALPHA-sources.jar: network/aika/debugger/neurons/NeuronConsole.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package network.aika.debugger.neurons;


import network.aika.debugger.AbstractConsole;
import network.aika.neuron.Neuron;
import network.aika.neuron.Range;
import network.aika.neuron.Synapse;
import network.aika.neuron.activation.Activation;
import network.aika.neuron.activation.Link;
import network.aika.neuron.conjunctive.*;
import network.aika.sign.Sign;
import network.aika.utils.Utils;

import javax.swing.text.StyledDocument;

import static network.aika.sign.Sign.NEG;
import static network.aika.sign.Sign.POS;

/**
 * @author Lukas Molzberger
 */
public class NeuronConsole extends AbstractConsole {

    public void renderNeuronConsoleOutput(StyledDocument sDoc, Neuron n, Activation ref) {
        appendText(sDoc, (n.isTemplate() ? "Template " : "") + n.getClass().getSimpleName() + "\n", "headline");

        appendEntry(sDoc, "Id: ", "" + n.getId());
        appendEntry(sDoc, "Label: ", n.getLabel());
        if (n.isNetworkInput()) {
            appendEntry(sDoc, "Is Network Input Neuron: ", "" + n.isNetworkInput());
        }
        appendEntry(sDoc, "Bias: ", "" + n.getBias());

        Range range = !n.isTemplate() && ref != null ? ref.getAbsoluteRange() : null;
        appendEntry(sDoc, "Range: ", range != null ? "" + range : NOT_SET_STR);
        appendEntry(sDoc, "Frequency: ", "" + Utils.round(n.getFrequency()));
        try {
            appendEntry(sDoc, "N: ", "" + Utils.round(n.getSampleSpace().getN(range)));
        } catch(IllegalStateException e) {
            appendEntry(sDoc, "N: ", NOT_SET_STR);
        }
        appendEntry(sDoc, "SampleSpace: ", "" + n.getSampleSpace());
        appendEntry(sDoc, "P(POS): ", probabilityToString(POS, n, range));
        appendEntry(sDoc, "P(NEG): ", probabilityToString(NEG, n, range));
        appendEntry(sDoc, "Surprisal(POS): ", surprisalToString(POS, n, range));
        appendEntry(sDoc, "Surprisal(NEG): ", surprisalToString(NEG, n, range));
        appendEntry(sDoc, "Template Neuron: ", templatesToString(n));
    }

    private String templatesToString(Neuron<?, ?> n) {
        StringBuilder sb = new StringBuilder();
        n.getTemplateGroup().forEach(tn -> sb.append(tn.getId() + ":" + tn.getLabel() + ", "));
        return sb.toString();
    }

    public void renderSynapseConsoleOutput(StyledDocument sDoc, Synapse s, Link ref) {
        appendText(sDoc, (s.isTemplate() ? "Template " :"") + s.getClass().getSimpleName() + "\n", "headline");

        appendEntry(sDoc, "Weight: ", "" + s.getWeight());
        appendEntry(sDoc, "Propagate: ", "" + s.allowPropagate(null));
        appendEntry(sDoc, "Input: ", s.getInput().toString() + (s.isInputLinked() ? " (linked)" : ""));
        appendEntry(sDoc, "Output: ", s.getOutput().toString() + (s.isOutputLinked() ? " (linked)" : ""));
        if(s instanceof SamePatternSynapse) {
            appendEntry(sDoc, "Loose Binding:", "" + s.allowLooseLinking());
        }

        if (s instanceof PositiveFeedbackSynapse) {
            PositiveFeedbackSynapse pfs = ((PositiveFeedbackSynapse) s);
            appendEntry(sDoc, "Feedback Bias:", "" + pfs.getFeedbackBias());
            appendEntry(sDoc, "Feedback Weight:", "" + pfs.getFeedbackWeight());
        }
        Range range = !s.isTemplate() && ref != null && ref.getInput() != null ? ref.getInput().getAbsoluteRange() : null;
        appendEntry(sDoc, "Range: ", range != null ? "" + range : NOT_SET_STR);

        appendEntry(sDoc, "Frequency(POS, POS): ", frequencyToString(POS, POS, s, range));
        appendEntry(sDoc, "Frequency(POS, NEG): ", frequencyToString(POS, NEG, s, range));
        appendEntry(sDoc, "Frequency(NEG, POS): ", frequencyToString(NEG, POS, s, range));
        appendEntry(sDoc, "Frequency(NEG, NEG): ", frequencyToString(NEG, NEG, s, range));
        try {
            appendEntry(sDoc, "N: ", "" + Utils.round(s.getSampleSpace().getN(range)));
        } catch(IllegalStateException e) {
            appendEntry(sDoc, "N: ", NOT_SET_STR);
        }
        appendEntry(sDoc, "SampleSpace: ", "" + s.getSampleSpace());
        appendEntry(sDoc, "P(POS, POS) :", probabilityToString(POS, POS, s, range));
        appendEntry(sDoc, "P(POS, NEG) :", probabilityToString(POS, NEG, s, range));
        appendEntry(sDoc, "P(NEG, POS) :", probabilityToString(NEG, POS, s, range));
        appendEntry(sDoc, "P(NEG, NEG) :", probabilityToString(NEG, NEG, s, range));
        appendEntry(sDoc, "Surprisal(POS, POS): ", surprisalToString(POS, POS, s, range));
        appendEntry(sDoc, "Surprisal(POS, NEG): ", surprisalToString(POS, NEG, s, range));
        appendEntry(sDoc, "Surprisal(NEG, POS): ", surprisalToString(NEG, POS, s, range));
        appendEntry(sDoc, "Surprisal(NEG, NEG): ", surprisalToString(NEG, NEG, s, range));
        appendEntry(sDoc, "Template: ", s.getTemplate().toString());
    }


    private String frequencyToString(Sign is, Sign os, Synapse s, Range range) {
        double N = s.getSampleSpace().getN(range);
        if(N == 0.0)
            return NOT_SET_STR;

        try {
            return "" + Utils.round(s.getFrequency(is, os, s.getSampleSpace().getN(range)));
        } catch(IllegalStateException e) {
            return NOT_SET_STR;
        }
    }

    private String probabilityToString(Sign s, Neuron n, Range range) {
        double N = n.getSampleSpace().getN(range);
        if(N == 0.0)
            return NOT_SET_STR;

        try {
            return "" + Utils.round(n.getProbability(s, N, false), 100000000.0);
        } catch(IllegalStateException e) {
            return NOT_SET_STR;
        }
    }

    private String probabilityToString(Sign is, Sign os, Synapse s, Range range) {
        double N = s.getSampleSpace().getN(range);
        if(N == 0.0)
            return NOT_SET_STR;

        try {
            return "" + Utils.round(s.getProbability(is, os, N, false), 100000000.0);
        } catch(IllegalStateException e) {
            return NOT_SET_STR;
        }
    }

    private String surprisalToString(Sign s, Neuron n, Range range) {
        double N = n.getSampleSpace().getN(range);
        if(N == 0.0)
            return NOT_SET_STR;

        try {
            return "" + Utils.round(n.getSurprisal(s, range, false));
        } catch(IllegalStateException e) {
            return NOT_SET_STR;
        }
    }

    private String surprisalToString(Sign is, Sign os, Synapse s, Range range) {
        double N = s.getSampleSpace().getN(range);
        if(N == 0.0)
            return NOT_SET_STR;

        try {
            return "" + Utils.round(s.getSurprisal(is, os, range, false));
        } catch(IllegalStateException e) {
            return NOT_SET_STR;
        }
    }
}

==> aika-debugger-2.0.4.ALPHA-sources.jar: network/aika/debugger/neurons/NeuronConsole.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package network.aika.debugger.neurons;


import network.aika.debugger.AbstractConsole;
import network.aika.debugger.neurons.renderer.NeuronConsoleRenderer;
import network.aika.debugger.neurons.renderer.PositiveFeedbackSynapseConsoleRenderer;
import network.aika.debugger.neurons.renderer.SamePatternSynapseConsoleRenderer;
import network.aika.debugger.neurons.renderer.SynapseConsoleRenderer;
import network.aika.neuron.Neuron;
import network.aika.neuron.Synapse;
import network.aika.neuron.activation.Activation;
import network.aika.neuron.activation.Link;
import network.aika.neuron.conjunctive.*;

import javax.swing.text.StyledDocument;

/**
 * @author Lukas Molzberger
 */
public class NeuronConsole extends AbstractConsole {

    public void renderNeuronConsoleOutput(StyledDocument sDoc, Neuron n, Activation ref) {
        NeuronConsoleRenderer neuronRenderer = new NeuronConsoleRenderer(ref);
        neuronRenderer.render(sDoc, n);
    }

    public void renderSynapseConsoleOutput(StyledDocument sDoc, Synapse s, Link ref) {
        SynapseConsoleRenderer synRenderer;

        if(s instanceof PositiveFeedbackSynapse<?,?>) {
            synRenderer = new PositiveFeedbackSynapseConsoleRenderer(ref);
        } else if(s instanceof SamePatternSynapse) {
            synRenderer = new SamePatternSynapseConsoleRenderer(ref);
        } else {
            synRenderer = new SynapseConsoleRenderer(ref);
        }
        synRenderer.render(sDoc, s);
    }

}
